@@ -176,6 +176,7 @@ class Variable(VariableInterface):
         Table = "table"
         Boolean = "bool"
         Object = "object"
+        Tristate = "bool3"
 
     # label of variable
     label = None
@@ -220,6 +221,7 @@ class Variable(VariableInterface):
 
     On = "on"
     Off = "off"
+    Auto = "auto"
     EmptyTable = [[]]
 
     Readonly = READONLY
